@@ -12,21 +12,9 @@ Usage:
 
 parser = ArgumentParser(...)
 [...]
-sub = parser.add_subparsers(title="commands", dest="command", description="available commands")
-
-# Registering commands
-commands = {}
-for command, method in Subclass.get_commands(prefix="prefix_"):
-	Subclass.set_subparser_for(command, method, sub)
-	commands[command] = method
-[...]
-args = parser.parse_args()
-
-if args.command:
-	cmd = Subclass(...)
-	cmd.dispatch_command(commands, args)
-else:
-	parser.print_usage()
+cmd.add_subparsers(parser, prefixes=["get_", ...], delim="_", title="commands", description="available commands")
+cmd = Subclass(...)
+cmd.dispatch_command(commands, args)
 """
 
 from ast import literal_eval
@@ -212,7 +200,6 @@ class Command():
 						else:
 							c.add_argument(label, type=arg["type"], choices=arg["values"], default=arg["values"][0], nargs="?", help=arg["help_line"])
 					else:
-						print(arg)
 						c.add_argument(arg["alias"], arg["name"], type=arg["type"], help=arg["help_line"])
 
 	def has_option(self, method, option):
